@@ -4,7 +4,7 @@
 # For licensing, see LICENSE.SPECS
 #
 
-if !defined?(RUBY_ENGINE) || RUBY_ENGINE == 'ruby' || RUBY_ENGINE == 'rbx'
+if RUBY_ENGINE == 'ruby' || RUBY_ENGINE == 'rbx'
   require "mkmf"
 
   create_makefile("embed_test")
