@@ -5,6 +5,7 @@
 
 require File.expand_path(File.join(File.dirname(__FILE__), "spec_helper"))
 
+module VariadicSpec
 describe "Function with variadic arguments" do
   module LibTest
     extend FFI::Library
@@ -119,7 +120,7 @@ describe "Function with variadic arguments" do
     res = Ractor.new do
       pr = proc { 42.0 }
       LibTest.testCallbackVrDva(3.0, :cbVrD, pr)
-    end.take
+    end.value
 
     expect(res).to be_within(0.0000001).of(45.0)
   end
@@ -177,3 +178,4 @@ describe "Function with variadic arguments" do
     end
   end
 end
+end
